/* 
 * Copyright (C) 2002 - David W. Durham
 * 
 * This file is part of ReZound, an audio editing application.
 * 
 * ReZound is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 * 
 * ReZound is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 */

#ifndef __EditActions_H__
#define __EditActions_H__

#include "../../../config/common.h"

#include "CCropEdit.h"
#include "CCopyCutDeleteEdit.h"
#include "CCopyCutToNewEdit.h"
#include "CMuteEdit.h"
#include "CSelectionEdit.h"
#include "CPasteEdit.h"
#include "CPasteAsNewEdit.h"
//#include "CTrimEdit.h"
#include "CInsertSilenceEdit.h"
#include "CRotateEdit.h"
#include "CSwapChannelsEdit.h"
#include "CAddChannelsEdit.h"
#include "CDuplicateChannelEdit.h"
#include "CRemoveChannelsEdit.h"



#endif
